Calculate Normalized Preference Distance Computes the weighted normalized Euclidean distance between a set of fitness vectors and a set of reference points.
calc_norm_pref_distance(fitness, ref_points, weight, ideal_point, nadir_point)A matrix of distances where element (i, j) is the distance from fitness to ref_points.
A matrix of fitness values.
A matrix of reference points.
A numeric vector of weights for each objective.
A numeric vector of ideal point values.
A numeric vector of nadir point values.