Functions to evaluate the quality of the results obtained by the algorithms, evaluating their diversity and convergence, providing or not some parameters to compare.
generational_distance(front, true_pareto_front, p, inverted, plus)A vector with the measurement metric.
a N×M matrix where N is the number of points and M is the number of objectives.
a N×M matrix where N is the number of points and M is the number of objectives.
is the power in which the normalized distance is calculated.
if TRUE then computes IGD.
if TRUE then computes the GD+.
Francisco Benitez
Lamont, G., & Veldhuizen, D.V. (1999). Multiobjective evolutionary algorithms: classifications, analyses, and new innovations.