Learn R Programming

rmoo (version 0.3.2)

rmoo_Mutation: Mutation operators in non-dominated genetic algorithms

Description

Functions implementing mutation non-dominated genetic operator.

Usage

rmoobin_raMutation(object, parent)

rmooreal_raMutation(object, parent) rmooreal_polMutation(object, parent, eta = 20, indpb = 0.5)

rmooperm_simMutation(object, parent)

Value

Return a vector of values containing the mutated string.

Arguments

object

An object of class "nsga", "nsga2" or "nsga3" usually resulting from a call to function nsga, nsga2, nsga3.

parent

A vector of values for the parent from the current population where mutation should occur.

eta

Distribution parameter for mutation operator.

indpb

Independent mutation probability.

Author

Francisco Benitez

References

Scrucca, L. (2017) On some extensions to 'GA' package: hybrid optimisation, parallelisation and islands evolution. The R Journal, 9/1, 187-206, doi: 10.32614/RJ-2017-008.