Functions implementing crossover operators for non-dominated
genetic algorithms. rmoo_spCrossover (and its typed variants
rmoobin_, rmooreal_, rmooint_) performs single-point
crossover; rmooreal_sbxCrossover performs simulated binary
crossover; rmooperm_oxCrossover performs order crossover for
permutation representations.
rmooreal_sbxCrossover(object, parents, eta = 20, indpb = 0.5)rmoo_spCrossover(object, parents)
rmoobin_spCrossover(object, parents)
rmooreal_spCrossover(object, parents)
rmooint_spCrossover(object, parents)
rmooperm_oxCrossover(object, parents)
A list with two elements:
A matrix of dimension 2 × nVars containing the generated offspring.
A 2 × nObj matrix of NA values, indicating that
offspring fitness has not yet been evaluated.
An object of class "nsga", "nsga2", or
"nsga3", usually from a call to nsga,
nsga2, or nsga3.
A two-element integer vector indexing the parents from the current population.
The distribution index. A higher eta produces offspring closer to the parents, while a lower eta allows for larger differences.
The probability of a particular gene being crossed.
Francisco Benitez
Scrucca, L. (2017) On some extensions to 'GA' package: hybrid optimisation, parallelisation and islands evolution. The R Journal, 9/1, 187--206, tools:::Rd_expr_doi("10.32614/RJ-2017-008").
nsga(), nsga2(),
nsga3()