rnsga2-class: Class 'rnsga2'

rnsga2-classR Documentation

Class 'rnsga2'

Description

The class 'rnsga2' is instantiated within the execution of rmoo and will be returned as a result of it. All data generated during execution will be stored in it.

Slots

crowdingDistance

Crowding-comparison approach to estimate of the perimeter of the cuboid formed by using the nearest neighbors as the vertices.

reference_points

R-NSGA-II uses a set of reference points defined by the user to ensure diversity in obtained solutions.

extreme_points

are selected using the ASF in the (PerformScalarizing()). Necessary in the nadir point generation.

smin

Index used to obtain the extreme points.

Examples

showClass('rnsga2')

rmoo documentation built on May 4, 2026, 1:06 a.m.