Functions implementing mutation non-dominated genetic operator.
rmoobin_raMutation(object, parent) rmooreal_raMutation(object, parent)
rmooreal_polMutation(object, parent, eta = 20, indpb = 0.5)
rmooperm_simMutation(object, parent)
Return a vector of values containing the mutated string.
An object of class "nsga", "nsga2" or "nsga3" usually resulting from a call to function nsga, nsga2, nsga3.
A vector of values for the parent from the current population where mutation should occur.
Distribution parameter for mutation operator.
Independent mutation probability.
Francisco Benitez
Scrucca, L. (2017) On some extensions to 'GA' package: hybrid optimisation, parallelisation and islands evolution. The R Journal, 9/1, 187-206, doi: 10.32614/RJ-2017-008.