Produces two children by randomly swapping genes between two parents with equal probability at each locus. Each gene is inherited from either parent independently, giving maximum gene-level mixing.
rmoo_uxCrossover(object, parents)rmooint_uxCrossover(object, parents)
rmoobin_uxCrossover(object, parents)
A list with children (2 × n integer matrix) and
fitness (2 × nObj NA matrix).
MOEA object with slots population and fitness.
Integer vector of length 2 with the parent row indices.