The class 'rnsga2' is instantiated within the execution of rmoo and will be
returned as a result of it. All data generated during execution will be
stored in it.
Arguments
Slots
crowdingDistance
Crowding-comparison approach to estimate of the
perimeter of the cuboid formed by using the nearest neighbors as the vertices.
reference_points
R-NSGA-II uses a set of reference points defined by the user to
ensure diversity in obtained solutions.
extreme_points
are selected using the ASF in the (PerformScalarizing()).
Necessary in the nadir point generation.